from setuptools import setup, find_packages

setup(
    name='ali-integral',
    version='0.1.0',
    description='A Python library for calculating Information Flux at the Cauchy Horizon',
    author='Ali (Troxter222)',
    packages=find_packages(),
    install_requires=[
        'numpy',
        'matplotlib',
        'scipy'
    ],
)